<?php
/*
 * Plugin Name: Matt's Quiz
 * Plugin URI: http://www.mattsmarketingblog.com
 * Description: Matt's Quiz plugin
 * Author: Alex Litviniuk
 * Version: 1.1
 * Author URI: http://www.agilewebdevelopers.com
*/

define('QUIZES_OPTION_NAME', 'mattsquizes');

add_action('admin_menu', array('Matts_Quiz_Plugin', 'admin_menu'));
add_action('admin_head', array('Matts_Quiz_Plugin', 'admin_head'));

add_action('wp_head', array('Matts_Quiz_Plugin', 'wp_head'));

add_shortcode('matts-quiz', array('Matts_Quiz_Plugin', 'matts_quiz_shortcode'));

add_filter('widget_text', 'do_shortcode');

class Matts_Quiz_Plugin
{

    function admin_menu()
    {

        add_menu_page('Matt\'s Quiz Plugin', 'Matt\'s Quiz', 'manage_options', 'mattsquiz-main', array('Matts_Quiz_Plugin', 'settings_page'));
        add_submenu_page('mattsquiz-main', 'Settings', 'Settings', 'manage_options', 'mattsquiz-settings', array('Matts_Quiz_Plugin', 'settings_page'));

    }

    function wp_head()
    {
        wp_enqueue_script('jquery');
    }

    function settings_page()
    {
        global $edit_quiz;
        $edit_quiz = false;
        if ($_GET['action'] == 'create' || $_POST['action'] == 'create-now') {
            include 'includes/edit-form.php';
        } else if ($_GET['action'] == 'edit') {
            $edit_quiz = $_GET['name'];
            include 'includes/edit-form.php';
        } else if ($_GET['action'] == 'remove') {

            $quizes = get_option(QUIZES_OPTION_NAME);
            unset($quizes[stripslashes_deep($_GET['name'])]);
            update_option(QUIZES_OPTION_NAME, $quizes);

            echo '<script>location.href="', admin_url('?page=mattsquiz-main&message=removed') . '";</script>';

        } else {
            include 'includes/main-form.php';
        }
    }

    function admin_head()
    {
        ?>
    <link rel="stylesheet" href="<?php echo plugin_dir_url(__FILE__);?>css/admin-style.css">
    <link rel="stylesheet" href="<?php echo plugin_dir_url(__FILE__);?>js/css/ui-lightness/jquery-ui-1.8.18.custom.css">
    <script type="text/javascript"
            href="<?php echo plugin_dir_url(__FILE__);?>js/jquery-ui-1.8.18.custom.min.js"></script>
    <?php
    }

    function matts_quiz_shortcode($atts)
    {

        $name = $atts['id'];
        $quizes = get_option(QUIZES_OPTION_NAME);
        $quiz = $quizes[$name];

        ob_start();
        ?>
    <style type="text/css">
        .quiz {
            background: #e5f2c9;
            border: 5px solid #dbedb3;
            padding: 20px;
            font-family: Arial, sans-serif;
        }

        .quizStart {
            text-align: center;
        }

        .quiz .title {
            font-weight: bold;
            font-size: 24px;
        }

        .quiz .description {
            margin: 10px 0;
        }

        .quiz .actions {
            text-align: center;
            margin: 15px 0 0;
        }

        .quizQuestion .actions .next-btn,
        .quiz .actions .startQuiz {
            font-size: 14px;
            text-decoration: none;
            background: #89c509;
            color: #fff;
            font-weight: normal;
            padding: 0 5px;
            display: inline-block;
            border-radius: 5px;
            height: 25px;
            line-height: 25px;
        }

        .quizQuestion .title {
            font-size: 18px;
        }

        .quizQuestion .false-btn {
            margin-left: 10px;
        }

        .quizQuestion .false-btn,
        .quizQuestion .true-btn {
            background: #FF8B00;
            text-decoration: none;
            color: #fff;
            display: inline-block;
            border-radius: 5px;
            padding: 4px 7px;
            text-decoration: none !important;
            font-size: 14px;
            font-weight: bold;
            display: inline-block;
        }

        .stopQuiz {
            text-align: center;
        }

        .stopQuiz .description {
            font-size: 16px;
        }
    </style>
    <script type="text/javascript">
        var currentQuestionIndex = 0;
        var currentScore = 0;
        var quizName = '<?php echo stripslashes_deep($quiz['name']); ?>';
        var quizDescription = '<?php echo stripslashes_deep($quiz['description']); ?>';
        var quizQuestions = <?php echo json_encode($quiz['questions'])?>;
        var quizThankyou = '<?php echo stripslashes_deep($quiz['thankyou']); ?>';

        function startQuiz() {
            jQuery('.quizStart').removeClass('quizStart').addClass('quizQuestion');
            currentQuestionIndex = 0;
            currentScore = 0;

            if (quizThankyou == '') quizThankyou = 'Thank You!';

            showCurrentQuestion();
        }

        function stopQuiz() {
            jQuery('.quizQuestion').removeClass('quizQuestion').addClass('stopQuiz');

            jQuery('.quiz .title').html(quizThankyou);
            jQuery('.quiz .description').show().html('Your Score: ' + currentScore + ' / ' + quizQuestions.length);
            jQuery('.quiz .actions').html('');
        }

        function nextQuestion(bool) {

            var q = quizQuestions[currentQuestionIndex];

            currentQuestionIndex++;

            //end of quiz
            if (currentQuestionIndex >= quizQuestions.length) {
                stopQuiz();
            }

            // showing next question
            showCurrentQuestion();

        }

        function testQuestion(bool) {

            var q = quizQuestions[currentQuestionIndex];

            // saving current result
            if (q['answer'] == bool) {
                currentScore++;

                if (q['answer-text'].length == 0) {
                    nextQuestion();
                    return;
                }

                jQuery('.quiz .title').html('Correct! ' + q['answer-text']);

            } else {

                if (q['answer-text'].length == 0) {
                    nextQuestion();
                    return;
                }

                jQuery('.quiz .title').html('Incorrect! ' + q['answer-text']);

            }

            jQuery('.quiz .description').hide();
            jQuery('.quiz .actions').html('<a class="next-btn" href="#">Next</a>');

        }

        function showCurrentQuestion() {
            var q = quizQuestions[currentQuestionIndex];

            jQuery('.quiz .title').html(q['text']);
            jQuery('.quiz .description').hide();
            if (q['false-label'] == '') q['false-label'] = 'No';
            if (q['true-label'] == '') q['true-label'] = 'Yes';
            jQuery('.quiz .actions').html('<a class="true-btn" href="#">' + q['true-label'] + '</a>&nbsp;<a class="false-btn" href="#">' + q['false-label'] + '</a>');
        }

        jQuery(document).ready(function () {
            jQuery('.true-btn').live('click', function () {
                testQuestion(1);
            });
            jQuery('.false-btn').live('click', function () {
                testQuestion(0);
            });
            jQuery('.next-btn').live('click', function () {
                nextQuestion();
            });
        });
    </script>
    <div class="quiz quizStart">
        <div class="title"><?php echo stripslashes_deep($quiz['name']); ?></div>
        <div class="description"><?php echo stripslashes_deep($quiz['description']); ?></div>
        <div class="actions"><a class="startQuiz" href="javascript:startQuiz();">Start the Quiz!</a></div>
    </div>
    <?php



        return ob_get_clean();
    }
}